@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
 import itertools
+from typing import Iterable, Iterator, Tuple, Set
 
 
-def ranges_to_set(lst):
+def ranges_to_set(lst: Iterable[Tuple[int, int]]) -> Set[int]:
     """
     Convert a list of ranges to a set of numbers::
 
@@ -12,10 +12,10 @@ def ranges_to_set(lst):
     [1, 2, 3, 5, 6]
 
     """
-    return set(itertools.chain(*(range(x[0], x[1]+1) for x in lst)))
+    return set(itertools.chain(*(range(x[0], x[1] + 1) for x in lst)))
 
 
-def to_ranges(lst):
+def to_ranges(lst: Iterable[int]) -> Iterator[Tuple[int, int]]:
     """
     Convert a list of numbers to a list of ranges::
 
@@ -25,6 +25,5 @@ def to_ranges(lst):
 
     """
     for a, b in itertools.groupby(enumerate(lst), lambda t: t[1] - t[0]):
-        b = list(b)
-        yield b[0][1], b[-1][1]
-
+        c = list(b)
+        yield c[0][1], c[-1][1]
